==> bn-2.2.2.zip: bn/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2010 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'না';
$GLOBALS['__l10n']['Configuration successfully updated'] = 'কনফিগারেশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['Settings definition successfully updated'] = 'সেটিংস ডেফিনিশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['blog settings'] = 'ব্লগ সেটিংস';
$GLOBALS['__l10n']['Value'] = 'ভ্যালু';
$GLOBALS['__l10n']['Description'] = 'বিবরণ';
$GLOBALS['__l10n']['Akismet spam filter'] = 'Akismet স্প্যাম ফিল্টার';
$GLOBALS['__l10n']['Antispam'] = 'এন্টিস্প্যাম';
$GLOBALS['__l10n']['Delete junk comments older than'] = 'পুরোনো জাঙ্ক মন্তব্য মুছে ফেলুন';
$GLOBALS['__l10n']['days'] = 'দিন';
$GLOBALS['__l10n']['IP Blacklist / Whitelist Filter'] = 'IP কালোতালিকা / সাদাতালিকা ফিল্টার';
$GLOBALS['__l10n']['IP address has been successfully added.'] = 'IP এড্রেস সফলভাবে যোগ করা হয়েছে।';
$GLOBALS['__l10n']['IP addresses have been successfully removed.'] = 'IP এড্রেসসমূহ সফলভাবে মুছে ফেলা হয়েছে।';
$GLOBALS['__l10n']['Blacklist'] = 'কালোতালিকা';
$GLOBALS['__l10n']['Whitelist'] = 'সাদাতালিকা';
$GLOBALS['__l10n']['Add an IP address'] = 'IP এড্রেস যোগ করো';
$GLOBALS['__l10n']['Add'] = 'যোগ করুন';
$GLOBALS['__l10n']['No IP address in list.'] = 'লিস্টে কোনো IP এড্রেস নেই।';
$GLOBALS['__l10n']['IP list'] = 'IP লিস্ট';
$GLOBALS['__l10n']['Words Blacklist'] = 'শব্দের কালোতালিকা';
$GLOBALS['__l10n']['List'] = 'লিস্ট';
$GLOBALS['__l10n']['Spam'] = 'স্প্যাম';
$GLOBALS['__l10n']['Information'] = 'তথ্য';
$GLOBALS['__l10n']['Spam comments have been successfully deleted.'] = 'স্প্যাম মন্তব্যসমূহ সফলভাবে মুছে ফেলা হয়েছে।';
$GLOBALS['__l10n']['Junk comments:'] = 'জাঙ্ক মন্তব্যসমূহ:';
$GLOBALS['__l10n']['Published comments:'] = 'প্রকাশিত মন্তব্যসমূহ:';
$GLOBALS['__l10n']['Delete all spams'] = 'সব স্প্যাম মুছে ফেলুন';
$GLOBALS['__l10n']['Links'] = 'লিংকসমূহ';
$GLOBALS['__l10n']['All categories'] = 'সব ক্যাটাগরি';
$GLOBALS['__l10n']['Home page only'] = 'শুধু হোমপেজ';
$GLOBALS['__l10n']['You must provide a link title'] = 'আপনাকে অবশ্যই লিংকের শিরোনাম দিতে হবে';
$GLOBALS['__l10n']['You must provide a link URL'] = 'আপনাকে অবশ্যই লিংক URL দিতে হবে';
$GLOBALS['__l10n']['File is not in XML format.'] = 'ফাইলটি XML ফরম্যাটে নেই।';
$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = 'কনফিগারেশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['Delete all logs'] = 'সব স্প্যাম মুছে ফেলুন';
?>

==> bn-2.3.1.zip: bn/plugins.lang.php <==
<?php
# -- BEGIN LICENSE BLOCK ---------------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2011 Olivier Meunier & Association Dotclear
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK -----------------------------------------#
#
#
#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['no'] = 'না';
$GLOBALS['__l10n']['Configuration successfully updated'] = 'কনফিগারেশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['Settings definition successfully updated'] = 'সেটিংস ডেফিনিশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['blog settings'] = 'ব্লগ সেটিংস';
$GLOBALS['__l10n']['Value'] = 'ভ্যালু';
$GLOBALS['__l10n']['Description'] = 'বিবরণ';
$GLOBALS['__l10n']['Akismet spam filter'] = 'Akismet স্প্যাম ফিল্টার';
$GLOBALS['__l10n']['Antispam'] = 'এন্টিস্প্যাম';
$GLOBALS['__l10n']['Delete junk comments older than'] = 'পুরোনো জাঙ্ক মন্তব্য মুছে ফেলুন';
$GLOBALS['__l10n']['days'] = 'দিন';
$GLOBALS['__l10n']['IP Blacklist / Whitelist Filter'] = 'IP কালোতালিকা / সাদাতালিকা ফিল্টার';
$GLOBALS['__l10n']['IP address has been successfully added.'] = 'IP এড্রেস সফলভাবে যোগ করা হয়েছে।';
$GLOBALS['__l10n']['IP addresses have been successfully removed.'] = 'IP এড্রেসসমূহ সফলভাবে মুছে ফেলা হয়েছে।';
$GLOBALS['__l10n']['Blacklist'] = 'কালোতালিকা';
$GLOBALS['__l10n']['Whitelist'] = 'সাদাতালিকা';
$GLOBALS['__l10n']['Add an IP address'] = 'IP এড্রেস যোগ করো';
$GLOBALS['__l10n']['Add'] = 'যোগ করুন';
$GLOBALS['__l10n']['No IP address in list.'] = 'লিস্টে কোনো IP এড্রেস নেই।';
$GLOBALS['__l10n']['IP list'] = 'IP লিস্ট';
$GLOBALS['__l10n']['Words Blacklist'] = 'শব্দের কালোতালিকা';
$GLOBALS['__l10n']['List'] = 'লিস্ট';
$GLOBALS['__l10n']['Spam'] = 'স্প্যাম';
$GLOBALS['__l10n']['Information'] = 'তথ্য';
$GLOBALS['__l10n']['Spam comments have been successfully deleted.'] = 'স্প্যাম মন্তব্যসমূহ সফলভাবে মুছে ফেলা হয়েছে।';
$GLOBALS['__l10n']['Junk comments:'] = 'জাঙ্ক মন্তব্যসমূহ:';
$GLOBALS['__l10n']['Published comments:'] = 'প্রকাশিত মন্তব্যসমূহ:';
$GLOBALS['__l10n']['Delete all spams'] = 'সব স্প্যাম মুছে ফেলুন';
$GLOBALS['__l10n']['position'] = 'বিবরণ';
$GLOBALS['__l10n']['Links'] = 'লিংকসমূহ';
$GLOBALS['__l10n']['All categories'] = 'সব ক্যাটাগরি';
$GLOBALS['__l10n']['Home page only'] = 'শুধু হোমপেজ';
$GLOBALS['__l10n']['You must provide a link title'] = 'আপনাকে অবশ্যই লিংকের শিরোনাম দিতে হবে';
$GLOBALS['__l10n']['You must provide a link URL'] = 'আপনাকে অবশ্যই লিংক URL দিতে হবে';
$GLOBALS['__l10n']['File is not in XML format.'] = 'ফাইলটি XML ফরম্যাটে নেই।';
$GLOBALS['__l10n']['Theme configuration has been successfully updated.'] = 'কনফিগারেশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['Delete all logs'] = 'সব স্প্যাম মুছে ফেলুন';
$GLOBALS['__l10n']['Preferences successfully updated'] = 'কনফিগারেশন সফলভাবে আপডেট করা হয়েছে';
$GLOBALS['__l10n']['Preferences definition successfully updated'] = 'সেটিংস ডেফিনিশন সফলভাবে আপডেট করা হয়েছে';
?>
